@@ -24,8 +24,8 @@ pub type DeleteStatus = Vec<Status>;
 
 impl<'docker> Image<'docker> {
     impl_api_ep! {img: Image, resp
-        Inspect -> format!("/images/{}/json", img.name), Details
-        DeleteWithOpts -> format!("/images/{}", img.name), DeleteStatus
+        Inspect -> &format!("/images/{}/json", img.name), Details
+        DeleteWithOpts -> &format!("/images/{}", img.name), DeleteStatus, delete_json
     }
 
     api_doc! { Image => History
@@ -180,4 +180,17 @@ impl<'docker> Images<'docker> {
             .try_flatten_stream(),
         )
     }}
+
+    // api_doc! { Build => Prune
+    // /// Clear image build cache.
+    // |
+    pub async fn clear_cache(&self, opts: &ClearCacheOpts) -> Result<ClearCacheInfo> {
+        self.docker
+            .post_json(
+                construct_ep("/build/prune", opts.serialize()),
+                Payload::empty(),
+            )
+            .await
+    }
+    // }
 }
