@@ -1,5 +1,4 @@
 #![cfg(feature = "swarm")]
-#![cfg_attr(docsrs, doc(cfg(feature = "swarm")))]
 //! Manage Docker nodes
 //!
 //! Nodes are instances of the Engine participating in a swarm.
@@ -18,8 +17,8 @@ type Void = ();
 
 impl<'docker> Node<'docker> {
     impl_api_ep! {node: Node, resp
-        Inspect -> format!("/nodes/{}", node.name)
-        ForceDelete -> format!("/nodes/{}", node.name), Void
+        Inspect -> &format!("/nodes/{}", node.name)
+        ForceDelete -> &format!("/nodes/{}", node.name), Void
     }
 
     api_doc! { Node => Update
